@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,16 +15,15 @@
  * @category   Zend
  * @package    Zend_Auth
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: OpenIdTest.php 11879 2008-10-11 19:46:33Z alexander $
+ * @version    $Id$
  */
 
 
 /**
  * PHPUnit_Framework_TestCase
  */
-require_once 'PHPUnit/Framework/TestCase.php';
 
 /**
  * Zend_OpenId_ResponseHelper
@@ -64,8 +62,9 @@ require_once 'Zend/Http/Client/Adapter/Test.php';
  * @category   Zend
  * @package    Zend_Auth
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Auth
  */
 class Zend_Auth_Adapter_OpenIdTest extends PHPUnit_Framework_TestCase
 {
@@ -82,6 +81,13 @@ class Zend_Auth_Adapter_OpenIdTest extends PHPUnit_Framework_TestCase
         $adapter = new Zend_Auth_Adapter_OpenId(null, new Zend_OpenId_Consumer_Storage_File(dirname(__FILE__)."/_files"));
         $ret = $adapter->authenticate();
         $this->assertFalse($ret->isValid());
+        $this->assertSame("", $ret->getIdentity());
+        $this->assertSame(0, $ret->getCode());
+        $msgs = $ret->getMessages();
+        $this->assertTrue(is_array($msgs));
+        $this->assertSame(2, count($msgs));
+        $this->assertSame("Authentication failed", $msgs[0]);
+        $this->assertSame("Missing openid.mode", $msgs[1]);
     }
 
     public function testAuthenticateLoginInvalid()
@@ -89,6 +95,13 @@ class Zend_Auth_Adapter_OpenIdTest extends PHPUnit_Framework_TestCase
         $adapter = new Zend_Auth_Adapter_OpenId("%sd", new Zend_OpenId_Consumer_Storage_File(dirname(__FILE__)."/_files"));
         $ret = $adapter->authenticate();
         $this->assertFalse($ret->isValid());
+        $this->assertSame("%sd", $ret->getIdentity());
+        $this->assertSame(0, $ret->getCode());
+        $msgs = $ret->getMessages();
+        $this->assertTrue(is_array($msgs));
+        $this->assertSame(2, count($msgs));
+        $this->assertSame("Authentication failed", $msgs[0]);
+        $this->assertSame("Normalisation failed", $msgs[1]);
     }
 
     public function testAuthenticateLoginValid()
@@ -332,11 +345,27 @@ class Zend_Auth_Adapter_OpenIdTest extends PHPUnit_Framework_TestCase
 
     public function testAuthenticateVerifyInvalid()
     {
+        $_SERVER['SCRIPT_URI'] = "http://www.zf-test.com/test.php";
         unset($_SERVER['REQUEST_METHOD']);
-        $_GET = array('openid_mode'=>'id_res');
+        $_GET = array('openid_mode'=>'id_res',
+            "openid_return_to" => "http://www.zf-test.com/test.php",
+            "openid_assoc_handle" => self::HANDLE,
+            "openid_claimed_id" => self::ID,
+            "openid_identity" => self::REAL_ID,
+            "openid_response_nonce" => "2007-08-14T12:52:33Z46c1a59124fff",
+            "openid_signed" => "assoc_handle,return_to,claimed_id,identity,response_nonce,mode,signed",
+            "openid_sig" => "h/5AFD25NpzSok5tzHEGCVUkQSw="
+        );
         $adapter = new Zend_Auth_Adapter_OpenId(null, new Zend_OpenId_Consumer_Storage_File(dirname(__FILE__)."/_files"));
         $ret = $adapter->authenticate();
         $this->assertFalse($ret->isValid());
+        $this->assertSame(self::ID, $ret->getIdentity());
+        $this->assertSame(0, $ret->getCode());
+        $msgs = $ret->getMessages();
+        $this->assertTrue(is_array($msgs));
+        $this->assertSame(2, count($msgs));
+        $this->assertSame("Authentication failed", $msgs[0]);
+        $this->assertSame("Signature check failed", $msgs[1]);
     }
 
     public function testAuthenticateVerifyGetValid()
@@ -349,6 +378,7 @@ class Zend_Auth_Adapter_OpenIdTest extends PHPUnit_Framework_TestCase
         $storage->addAssociation(self::SERVER, self::HANDLE, self::MAC_FUNC, self::SECRET, $expiresIn);
         $storage->purgeNonces();
 
+        $_SERVER['SCRIPT_URI'] = "http://www.zf-test.com/test.php";
         unset($_SERVER['REQUEST_METHOD']);
         $_GET = array(
             "openid_return_to" => "http://www.zf-test.com/test.php",
@@ -375,6 +405,7 @@ class Zend_Auth_Adapter_OpenIdTest extends PHPUnit_Framework_TestCase
         $storage->addAssociation(self::SERVER, self::HANDLE, self::MAC_FUNC, self::SECRET, $expiresIn);
         $storage->purgeNonces();
 
+        $_SERVER['SCRIPT_URI'] = "http://www.zf-test.com/test.php";
         $_SERVER['REQUEST_METHOD'] = 'POST';
         $_GET = array();
         $_POST = array(
@@ -402,6 +433,7 @@ class Zend_Auth_Adapter_OpenIdTest extends PHPUnit_Framework_TestCase
         $storage->addAssociation(self::SERVER, self::HANDLE, self::MAC_FUNC, self::SECRET, $expiresIn);
         $storage->purgeNonces();
 
+        $_SERVER['SCRIPT_URI'] = "http://www.zf-test.com/test.php";
         $_SERVER['REQUEST_METHOD'] = 'GET';
         $_GET = array(
             "openid_ns"        => Zend_OpenId::NS_2_0,
