@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 7508 2008-01-19 03:12:38Z peptolab $
+ * @version    $Id$
  */
 
 
@@ -28,20 +27,22 @@
 require_once 'Zend/Db/TestSetup.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
+
 
 
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
 {
     /**
      * Test basic use of the Zend_Db_Select class.
+     *
+     * @return Zend_Db_Select
      */
     protected function _select()
     {
@@ -53,7 +54,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
     public function testSelect()
     {
         $select = $this->_select();
-        $this->assertType('Zend_Db_Select', $select,
+        $this->assertTrue($select instanceof Zend_Db_Select,
             'Expecting object of type Zend_Db_Select, got '.get_class($select));
         $stmt = $this->_db->query($select);
         $row = $stmt->fetch();
@@ -74,7 +75,27 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
     public function testSelectQuery()
     {
         $select = $this->_select();
-        $this->assertType('Zend_Db_Select', $select,
+        $this->assertTrue($select instanceof Zend_Db_Select,
+            'Expecting object of type Zend_Db_Select, got '.get_class($select));
+        $stmt = $select->query();
+        $row = $stmt->fetch();
+        $stmt->closeCursor();
+        $this->assertEquals(2, count($row)); // correct number of fields
+        $this->assertEquals(1, $row['product_id']); // correct data
+    }
+
+    /**
+     * ZF-2017: Test bind use of the Zend_Db_Select class.
+     * @group ZF-2017
+     */
+    public function testSelectQueryWithBinds()
+    {
+        $product_id = $this->_db->quoteIdentifier('product_id');
+
+        $select = $this->_select()->where("$product_id = :product_id")
+                                  ->bind(array(':product_id' => 1));
+
+        $this->assertTrue($select instanceof Zend_Db_Select,
             'Expecting object of type Zend_Db_Select, got '.get_class($select));
         $stmt = $select->query();
         $row = $stmt->fetch();
@@ -321,7 +342,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
                    ->columns('product_id');
             $this->fail('Expected exception of type "Zend_Db_Select_Exception"');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Select_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Select_Exception,
                               'Expected exception of type "Zend_Db_Select_Exception", got ' . get_class($e));
             $this->assertEquals("No table has been specified for the FROM clause", $e->getMessage());
         }
@@ -609,7 +630,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
             $select->foo();
             $this->fail('Expected exception of type "Zend_Db_Select_Exception"');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Select_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Select_Exception,
                               'Expected exception of type "Zend_Db_Select_Exception", got ' . get_class($e));
             $this->assertEquals("Unrecognized method 'foo()'", $e->getMessage());
         }
@@ -655,7 +676,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
             $select->joinFooUsing();
             $this->fail('Expected exception of type "Zend_Db_Select_Exception"');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Select_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Select_Exception,
                               'Expected exception of type "Zend_Db_Select_Exception", got ' . get_class($e));
             $this->assertEquals("Unrecognized method 'joinFooUsing()'", $e->getMessage());
         }
@@ -681,7 +702,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
             $select->joinCrossUsing("zfbugs_products", "$product_id");
             $this->fail('Expected exception of type "Zend_Db_Select_Exception"');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Select_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Db_Select_Exception,
                               'Expected exception of type "Zend_Db_Select_Exception", got ' . get_class($e));
             $this->assertEquals("Cannot perform a joinUsing with method 'joinCrossUsing()'", $e->getMessage());
         }
@@ -733,7 +754,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
                          . $this->_db->quoteIdentifier('subqueryTable') . '))';
         $this->assertEquals($query, $cmp);
     }
-    
+
     protected function _selectWhereArray()
     {
         $product_id = $this->_db->quoteIdentifier('product_id');
@@ -743,7 +764,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
             ->where("$product_id IN (?)", array(1, 2, 3));
         return $select;
     }
-    
+
     public function testSelectWhereArray()
     {
         $select = $this->_selectWhereArray();
@@ -860,7 +881,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         setlocale(LC_ALL, $locale);
     }
 
-    /** 
+    /**
      * Test adding an OR WHERE clause to a Zend_Db_Select object.
      */
     protected function _selectWhereOr()
@@ -1208,6 +1229,86 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(1, $result[0]['product_id']);
     }
 
+    protected function _selectOrderByPosition()
+    {
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->order('2');
+        return $select;
+    }
+
+    public function testSelectOrderByPosition()
+    {
+        $select = $this->_selectOrderByPosition();
+
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+
+        $this->assertEquals(2, $result[0]['product_id']);
+        $this->assertEquals(3, $result[1]['product_id']);
+        $this->assertEquals(1, $result[2]['product_id']);
+    }
+
+    protected function _selectOrderByPositionAsc()
+    {
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->order('2 ASC');
+        return $select;
+    }
+
+    public function testSelectOrderByPositionAsc()
+    {
+        $select = $this->_selectOrderByPositionAsc();
+
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+
+        $this->assertEquals(2, $result[0]['product_id']);
+        $this->assertEquals(3, $result[1]['product_id']);
+        $this->assertEquals(1, $result[2]['product_id']);
+    }
+
+    protected function _selectOrderByPositionDesc()
+    {
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->order('2 DESC');
+        return $select;
+    }
+
+    public function testSelectOrderByPositionDesc()
+    {
+        $select = $this->_selectOrderByPositionDesc();
+
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+
+        $this->assertEquals(1, $result[0]['product_id']);
+        $this->assertEquals(3, $result[1]['product_id']);
+        $this->assertEquals(2, $result[2]['product_id']);
+    }
+
+    protected function _selectOrderByMultiplePositions()
+    {
+        $select = $this->_db->select()
+            ->from('zfproducts')
+            ->order(array('2 DESC', '1 DESC'));
+        return $select;
+    }
+
+    public function testSelectOrderByMultiplePositions()
+    {
+        $select = $this->_selectOrderByMultiplePositions();
+
+        $stmt = $this->_db->query($select);
+        $result = $stmt->fetchAll();
+
+        $this->assertEquals(1, $result[0]['product_id']);
+        $this->assertEquals(3, $result[1]['product_id']);
+        $this->assertEquals(2, $result[2]['product_id']);
+    }
+
     protected function _selectOrderByDesc()
     {
         $select = $this->_db->select()
@@ -1312,6 +1413,17 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(3, $result[0]['product_id']);
     }
 
+    /**
+     * @group ZF-4246
+     */
+    protected function _checkExtraField($result)
+    {
+        // Check that extra field ZEND_DB_ROWNUM isn't present
+        // (particulary with Db2 & Oracle)
+        $this->assertArrayNotHasKey('zend_db_rownum', $result);
+        $this->assertArrayNotHasKey('ZEND_DB_ROWNUM', $result);
+    }
+
     /**
      * Test adding a LIMIT clause to a Zend_Db_Select object.
      */
@@ -1324,6 +1436,9 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         return $select;
     }
 
+    /**
+     * @group ZF-4246
+     */
     public function testSelectLimit()
     {
         $select = $this->_selectLimit();
@@ -1331,6 +1446,26 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetchAll();
         $this->assertEquals(1, count($result));
         $this->assertEquals(1, $result[0]['product_id']);
+        $this->_checkExtraField($result[0]);
+    }
+
+    /**
+     * @group ZF-5263
+     * @group ZF-4246
+     */
+    public function testSelectLimitFetchCol()
+    {
+        $product_id = $this->_db->quoteIdentifier('product_id');
+
+        $select = $this->_db->select()
+            ->from('zfproducts', 'product_name')
+            ->where($product_id . ' = ?', 3)
+            ->limit(1);
+
+        $result = $this->_db->fetchCol($select);
+        $this->assertEquals(1, count($result));
+        $this->assertEquals('OS X', $result[0]);
+        $this->_checkExtraField($result);
     }
 
     protected function _selectLimitNone()
@@ -1342,12 +1477,16 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         return $select;
     }
 
+    /**
+     * @group ZF-4246
+     */
     public function testSelectLimitNone()
     {
         $select = $this->_selectLimitNone();
         $stmt = $this->_db->query($select);
         $result = $stmt->fetchAll();
         $this->assertEquals(3, count($result));
+        $this->_checkExtraField($result[0]);
     }
 
     protected function _selectLimitOffset()
@@ -1359,6 +1498,9 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         return $select;
     }
 
+    /**
+     * @group ZF-4246
+     */
     public function testSelectLimitOffset()
     {
         $select = $this->_selectLimitOffset();
@@ -1366,6 +1508,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetchAll();
         $this->assertEquals(1, count($result));
         $this->assertEquals(2, $result[0]['product_id']);
+        $this->_checkExtraField($result[0]);
     }
 
     /**
@@ -1380,6 +1523,9 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         return $select;
     }
 
+    /**
+     * @group ZF-4246
+     */
     public function testSelectLimitPageOne()
     {
         $select = $this->_selectLimitPageOne();
@@ -1387,6 +1533,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetchAll();
         $this->assertEquals(1, count($result));
         $this->assertEquals(1, $result[0]['product_id']);
+        $this->_checkExtraField($result[0]);
     }
 
     protected function _selectLimitPageTwo()
@@ -1398,6 +1545,9 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         return $select;
     }
 
+    /**
+     * @group ZF-4246
+     */
     public function testSelectLimitPageTwo()
     {
         $select = $this->_selectLimitPageTwo();
@@ -1405,6 +1555,7 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $result = $stmt->fetchAll();
         $this->assertEquals(1, count($result));
         $this->assertEquals(2, $result[0]['product_id']);
+        $this->_checkExtraField($result[0]);
     }
 
     /**
@@ -1458,4 +1609,152 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(1, $result[0]['id']);
     }
 
+    /**
+     * @group ZF-4772
+     * @expectedException Zend_Db_Select_Exception
+     */
+    public function testSelectUnionNoArrayThrowsException()
+    {
+        $this->_db->select()->union('string');
+    }
+
+    /**
+     * @group ZF-4772
+     * @expectedException Zend_Db_Select_Exception
+     */
+    public function testSelectUnionInvalidUnionTypeThrowsException()
+    {
+        $this->_db->select()->union(array(), 'foo');
+    }
+
+    /**
+     * @group ZF-6653
+     */
+    public function testSelectIsTheSameWhenCallingFromAndJoinInDifferentOrders()
+    {
+        $selectFromThenJoin = $this->_db->select();
+        $selectFromThenJoin->from(array('f' => 'foo'), array('columnfoo'))
+            ->joinLeft(array('b' => 'bar'), 'f.columnfoo2 = b.barcolumn2', array('baralias' => 'barcolumn'));
+
+        $selectJoinThenFrom = $this->_db->select();
+        $selectJoinThenFrom->joinLeft(array('b' => 'bar'), 'f.columnfoo2 = b.barcolumn2', array('baralias' => 'barcolumn'))
+            ->from(array('f' => 'foo'), array('columnfoo'));
+
+        $sqlSelectFromThenJoin = $selectFromThenJoin->assemble();
+        $sqlSelectJoinThenFrom = $selectJoinThenFrom->assemble();
+        $this->assertEquals($sqlSelectFromThenJoin, $sqlSelectJoinThenFrom);
+    }
+
+    /**
+     * @group ZF-6653
+     */
+    public function testSelectIsTheSameWhenCallingMultipleFromsAfterJoin()
+    {
+        $selectFromThenJoin = $this->_db->select();
+        $selectFromThenJoin->from(array('f' => 'foo'), array('columnfoo'))
+            ->from(array('d' => 'doo'), array('columndoo'))
+            ->joinLeft(array('b' => 'bar'), 'f.columnfoo2 = b.barcolumn2', array('baralias' => 'barcolumn'));
+
+        $selectJoinThenFrom = $this->_db->select();
+        $selectJoinThenFrom->joinLeft(array('b' => 'bar'), 'f.columnfoo2 = b.barcolumn2', array('baralias' => 'barcolumn'))
+            ->from(array('f' => 'foo'), array('columnfoo'))
+            ->from(array('d' => 'doo'), array('columndoo'));
+
+        $sqlSelectFromThenJoin = $selectFromThenJoin->assemble();
+        $sqlSelectJoinThenFrom = $selectJoinThenFrom->assemble();
+        $this->assertEquals($sqlSelectFromThenJoin, $sqlSelectJoinThenFrom);
+    }
+
+    /**
+     * @group ZF-6653
+     */
+    public function testSelectWithMultipleFromsAfterAJoinWillProperlyOrderColumns()
+    {
+        $select = $this->_selectWithMultipleFromsAfterAJoinWillProperlyOrderColumns();
+        $quote = $this->_db->getQuoteIdentifierSymbol();
+        $target = 'SELECT `f`.`columnfoo`, `d`.`columndoo`, `b`.`barcolumn` AS `baralias` FROM ' . $this->_db->quoteTableAs('foo', 'f')
+            . "\n" . ' INNER JOIN ' . $this->_db->quoteTableAs('doo', 'd')
+            . "\n" . ' LEFT JOIN ' . $this->_db->quoteTableAs('bar', 'b') . ' ON f.columnfoo2 = b.barcolumn2';
+        if ($quote != '`') {
+            $target = str_replace('`', $quote, $target);
+        }
+        $this->assertEquals($target, $select->assemble());
+    }
+
+    protected function _selectWithMultipleFromsAfterAJoinWillProperlyOrderColumns()
+    {
+        $selectJoinThenFrom = $this->_db->select();
+        $selectJoinThenFrom->joinLeft(array('b' => 'bar'), 'f.columnfoo2 = b.barcolumn2', array('baralias' => 'barcolumn'))
+            ->from(array('f' => 'foo'), array('columnfoo'))
+            ->from(array('d' => 'doo'), array('columndoo'));
+        return $selectJoinThenFrom;
+    }
+
+    public function testSerializeSelect()
+    {
+        /* checks if the adapter has effectively gotten serialized,
+           no exceptions are thrown here, so it's all right */
+        $serialize = serialize($this->_select());
+        $this->assertTrue(is_string($serialize));
+    }
+    
+    /**
+     * @group ZF-3792
+     */
+    public function testJoinUsingActuallyGeneratesAnInnerJoinOnForCompatibilityReasons()
+    {
+        $table_A = $this->_db->quoteTableAs('A');
+        $table_B = $this->_db->quoteTableAs('B');
+        $colname = $this->_db->quoteIdentifier('colname');
+        
+        $s = $this->_db->select()->from('A')->joinUsing('B', $colname);
+        $this->assertContains("JOIN {$table_B} ON {$table_B}.{$colname} = {$table_A}.{$colname}", $s->assemble());
+    }
+
+    /**
+     * @group ZF-5953
+     */
+    public function testJoinUsingAllowsSpecifyingMultipleColumnsViaAnArray()
+    {
+        $table_A = $this->_db->quoteTableAs('A');
+        $table_B = $this->_db->quoteTableAs('B');
+        $colOne  = $this->_db->quoteIdentifier('colOne');
+        $colTwo  = $this->_db->quoteIdentifier('colTwo');
+        
+        $s = $this->_db->select()->from('A')->joinUsing('B', array($colOne,$colTwo));
+        $this->assertContains(
+            "JOIN {$table_B} ON {$table_B}.{$colOne} = {$table_A}.{$colOne}"
+            . " AND {$table_B}.{$colTwo} = {$table_A}.{$colTwo}",
+            $s->assemble()
+        );
+    }
+
+    /**
+     * @group ZF-3309
+     */
+    public function testJoinUsingUsesTableNameOfTableBeingJoinedWhenAliasNotDefined()
+    {
+        $table1 = $this->_db->quoteTableAs('table1');
+        $table2 = $this->_db->quoteTableAs('table2');
+        $colname = $this->_db->quoteIdentifier('column1');
+        
+        $select = $this->_db->select();
+        $select->from('table1')->joinUsing('table2', $colname);
+        $this->assertRegexp("/ON {$table2}.{$colname}/s", $select->assemble());
+    }
+    
+    /**
+     * @group ZF-3309
+     */
+    public function testJoinUsingUsesAliasOfTableBeingJoinedWhenAliasIsDefined()
+    {
+        $table1 = $this->_db->quoteTableAs('table1');
+        $table2_alias = $this->_db->quoteTableAs('t2');
+        $colname = $this->_db->quoteIdentifier('column1');
+        
+        $select = $this->_db->select();
+        $select->from('table1')->joinUsing(array('t2'=>'table2'), $colname);
+        $this->assertRegexp("/ON {$table2_alias}.{$colname}/s", $select->assemble());
+    }    
+    
 }
