@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Common.php 7508 2008-01-19 03:12:38Z peptolab $
+ * @version    $Id$
  */
 
 
@@ -27,20 +26,15 @@
  */
 require_once 'Zend/Db/Expr.php';
 
-/**
- * PHPUnit_Util_Filter
- */
-require_once 'PHPUnit/Util/Filter.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
 
 
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 abstract class Zend_Db_TestUtil_Common
@@ -62,7 +56,7 @@ abstract class Zend_Db_TestUtil_Common
 
     protected function _getSqlCreateTable($tableName)
     {
-        return 'CREATE TABLE ' . $this->_db->quoteIdentifier($tableName, true);
+        return 'CREATE TABLE ' . $this->getAdapter()->quoteIdentifier($tableName, true);
     }
 
     protected function _getSqlCreateTableType()
@@ -72,7 +66,7 @@ abstract class Zend_Db_TestUtil_Common
 
     protected function _getSqlDropTable($tableName)
     {
-        return 'DROP TABLE ' . $this->_db->quoteIdentifier($tableName, true);
+        return 'DROP TABLE ' . $this->getAdapter()->quoteIdentifier($tableName, true);
     }
 
     public function getSqlType($type)
@@ -103,13 +97,13 @@ abstract class Zend_Db_TestUtil_Common
             $pKey = $columns['PRIMARY KEY'];
             unset($columns['PRIMARY KEY']);
             foreach (explode(',', $pKey) as $pKeyCol) {
-                $pKeys[] = $this->_db->quoteIdentifier($pKeyCol, true);
+                $pKeys[] = $this->getAdapter()->quoteIdentifier($pKeyCol, true);
             }
             $pKey = implode(', ', $pKeys);
         }
 
         foreach ($columns as $columnName => $type) {
-            $col[] = $this->_db->quoteIdentifier($columnName, true) . ' ' . $this->getSqlType($type);
+            $col[] = $this->getAdapter()->quoteIdentifier($columnName, true) . ' ' . $this->getSqlType($type);
         }
 
         if ($pKey) {
@@ -118,9 +112,9 @@ abstract class Zend_Db_TestUtil_Common
 
         $sql .= implode(",\n\t", $col);
         $sql .= "\n)" . $this->_getSqlCreateTableType();
-        $result = $this->_rawQuery($sql);
+        $result = $this->_tryRawQuery($sql);
         if ($result === false) {
-            throw new Zend_Db_Exception("Statement failed:\n$sql\nError: " . $this->_db->getConnection()->error);
+            throw new Zend_Db_Exception("Statement failed:\n$sql\nError: " . $this->getAdapter()->getConnection()->error);
         }
         $this->_tables[$tableName] = true;
     }
@@ -138,9 +132,9 @@ abstract class Zend_Db_TestUtil_Common
         if (!$sql) {
             return;
         }
-        $result = $this->_rawQuery($sql);
+        $result = $this->_tryRawQuery($sql);
         if ($result === false) {
-            throw new Zend_Db_Exception("DROP TABLE statement failed:\n$sql\nError: " . $this->_db->getConnection()->error);
+            throw new Zend_Db_Exception("DROP TABLE statement failed:\n$sql\nError: " . $this->getAdapter()->getConnection()->error);
         }
         unset($this->_tables[$tableName]);
     }
@@ -165,9 +159,9 @@ abstract class Zend_Db_TestUtil_Common
         if (!$sql) {
             return;
         }
-        $result = $this->_rawQuery($sql);
+        $result = $this->_tryRawQuery($sql);
         if ($result === false) {
-            throw new Zend_Db_Exception("CREATE SEQUENCE statement failed:\n$sql\nError: " . $this->_db->getConnection()->error);
+            throw new Zend_Db_Exception("CREATE SEQUENCE statement failed:\n$sql\nError: " . $this->getAdapter()->getConnection()->error);
         }
         $this->_sequences[$sequenceName] = true;
     }
@@ -185,9 +179,9 @@ abstract class Zend_Db_TestUtil_Common
         if (!$sql) {
             return;
         }
-        $result = $this->_rawQuery($sql);
+        $result = $this->_tryRawQuery($sql);
         if ($result === false) {
-            throw new Zend_Db_Exception("DROP SEQUENCE statement failed:\n$sql\nError: " . $this->_db->getConnection()->error);
+            throw new Zend_Db_Exception("DROP SEQUENCE statement failed:\n$sql\nError: " . $this->getAdapter()->getConnection()->error);
         }
         unset($this->_sequences[$sequenceName]);
     }
@@ -210,7 +204,7 @@ abstract class Zend_Db_TestUtil_Common
         if (isset($param['dbname']) && strpos($param['dbname'], ':') === false) {
             return $param['dbname'];
         }
-        
+
         return null;
     }
 
@@ -224,6 +218,7 @@ abstract class Zend_Db_TestUtil_Common
         'Documents'     => 'zfdocuments',
         'Price'         => 'zfprice',
         'AltBugsProducts' => 'zfalt_bugs_products',
+        'CascadeRecursive' => 'zfalt_cascade_recursive'
     );
 
     public function getTableName($tableId)
@@ -297,6 +292,16 @@ abstract class Zend_Db_TestUtil_Common
             );
     }
 
+    protected function _getColumnsCascadeRecursive()
+    {
+        return array(
+            'item_id'       => 'INTEGER NOT NULL',
+            'item_parent'   => 'INTEGER NULL',
+            'item_data'     => 'VARCHAR(100)',
+            'PRIMARY KEY'   => 'item_id'
+        );
+    }
+
     protected function _getDataAccounts()
     {
         return array(
@@ -413,31 +418,76 @@ abstract class Zend_Db_TestUtil_Common
         );
     }
 
+    protected function _getDataCascadeRecursive()
+    {
+        return array(
+            array('item_id' => '1', 'item_parent' => NULL, 'item_data' => '1'),
+            array('item_id' => '2', 'item_parent' => '1', 'item_data' => '1.2'),
+            array('item_id' => '3', 'item_parent' => '1', 'item_data' => '1.3'),
+            array('item_id' => '4', 'item_parent' => '3', 'item_data' => '1.3.4'),
+            array('item_id' => '5', 'item_parent' => '3', 'item_data' => '1.3.5'),
+            array('item_id' => '6', 'item_parent' => NULL, 'item_data' => '6')
+        );
+    }
+
     public function populateTable($tableId)
     {
         $tableName = $this->getTableName($tableId);
         $data = $this->{'_getData'.$tableId}();
         foreach ($data as $row) {
-            $sql = 'INSERT INTO ' .  $this->_db->quoteIdentifier($tableName, true);
+            $sql = 'INSERT INTO ' .  $this->getAdapter()->quoteIdentifier($tableName, true);
             $cols = array();
             $vals = array();
             foreach ($row as $col => $val) {
-                $cols[] = $this->_db->quoteIdentifier($col, true);
+                $cols[] = $this->getAdapter()->quoteIdentifier($col, true);
                 if ($val instanceof Zend_Db_Expr) {
                     $vals[] = $val->__toString();
                 } else {
-                    $vals[] = $this->_db->quote($val);
+                    $vals[] = $this->getAdapter()->quote($val);
                 }
             }
             $sql .=        ' (' . implode(', ', $cols) . ')';
             $sql .= ' VALUES (' . implode(', ', $vals) . ')';
-            $result = $this->_rawQuery($sql);
+            $result = $this->_tryRawQuery($sql);
             if ($result === false) {
-                throw new Zend_Db_Exception("Statement failed:\n$sql\nError: " . $this->_db->getConnection()->error);
+                throw new Zend_Db_Exception("Statement failed:\n$sql\nError: " . $this->getAdapter()->getConnection()->error);
             }
         }
     }
 
+    protected function _getSqlCreateView($viewName)
+    {
+        return 'CREATE VIEW ' . $this->getAdapter()->quoteIdentifier($viewName, true);
+    }
+
+    protected function _getSqlDropView($viewName)
+    {
+        return 'DROP VIEW ' . $this->getAdapter()->quoteIdentifier($viewName, true);
+    }
+
+    public function createView()
+    {
+        $sql = $this->_getSqlCreateView('temp_view')
+             . ' AS SELECT * FROM '
+             . $this->getAdapter()->quoteIdentifier('zfbugs', true);
+        $result = $this->_tryRawQuery($sql);
+        if ($result === false) {
+            throw new Zend_Db_Exception("Statement failed:\n$sql\nError: " . $this->getAdapter()->getConnection()->error);
+        }
+    }
+
+    public function dropView()
+    {
+        $sql = $this->_getSqlDropView('temp_view');
+        if (!$sql) {
+            return;
+        }
+        $result = $this->_tryRawQuery($sql);
+        if ($result === false) {
+            throw new Zend_Db_Exception("Statement failed:\n$sql\nError: " . $this->getAdapter()->getConnection()->error);
+        }
+    }
+
     public function setUp(Zend_Db_Adapter_Abstract $db)
     {
         $this->setAdapter($db);
@@ -459,6 +509,11 @@ abstract class Zend_Db_TestUtil_Common
 
         $this->createTable('Price');
         $this->populateTable('Price');
+
+        $this->createTable('CascadeRecursive');
+        $this->populateTable('CascadeRecursive');
+
+        $this->createView();
     }
 
     public function setAdapter(Zend_Db_Adapter_Abstract $db)
@@ -466,11 +521,30 @@ abstract class Zend_Db_TestUtil_Common
         $this->_db = $db;
     }
 
+    protected function getAdapter()
+    {
+        if($this->_db == null) {
+            require_once "Zend/Db/Exception.php";
+            throw new Zend_Db_Exception("No adapter was set in TestUtils.");
+        }
+        return $this->_db;
+    }
+
     public function tearDown()
     {
+        $this->dropView();
         $this->dropTable();
         $this->dropSequence();
-        $this->_db->closeConnection();
+        $this->getAdapter()->closeConnection();
+    }
+
+    protected function _tryRawQuery($sql)
+    {
+        if($this->_db == null) {
+            require_once "Zend/Db/Exception.php";
+            throw new Zend_Db_Exception("No database adapter set.");
+        }
+        $this->_rawQuery($sql);
     }
 
     protected abstract function _rawQuery($sql);
