@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Format
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FormatTest.php 24593 2012-01-05 20:35:02Z matthew $
+ * @version    $Id$
  */
 
 /**
@@ -29,7 +29,7 @@ require_once 'Zend/Locale/Format.php';
  * @category   Zend
  * @package    Zend_Locale
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Locale
  */
@@ -96,8 +96,8 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(          '0,1234567', Zend_Locale_Format::toNumber(       0.1234567,$options));
         $this->assertEquals( '-1.234.567,12345',   Zend_Locale_Format::toNumber(-1234567.12345,  $options));
         $this->assertEquals(  '1.234.567,12345',   Zend_Locale_Format::toNumber( 1234567.12345,  $options));
-        $this->assertEquals(    '1234567,12345',   Zend_Locale_Format::toNumber( 1234567.12345,  array('locale' => 'ar_QA')));
-        $this->assertEquals(    '1234567,12345-',  Zend_Locale_Format::toNumber(-1234567.12345,  array('locale' => 'ar_QA')));
+        $this->assertEquals(  '1٬234٬567٫12345',   Zend_Locale_Format::toNumber( 1234567.12345,  array('locale' => 'ar_QA')));
+        $this->assertEquals(  '‏-1٬234٬567٫12345',  Zend_Locale_Format::toNumber(-1234567.12345,  array('locale' => 'ar_QA')));
         $this->assertEquals(  '12,34,567.12345',   Zend_Locale_Format::toNumber( 1234567.12345,  array('locale' => 'dz_BT')));
         $this->assertEquals(  '-1.234.567,12345',  Zend_Locale_Format::toNumber(-1234567.12345,  array('locale' => 'mk_MK')));
         $this->assertEquals(        '452.25',      Zend_Locale_Format::toNumber(     452.25,     array('locale' => 'en_US')));
@@ -199,8 +199,8 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         $this->assertEquals( '1.234.567,12345',   Zend_Locale_Format::toFloat( 1234567.12345,   $options));
 
         $options = array('locale' => 'ar_QA');
-        $this->assertEquals(    '1234567,12345',  Zend_Locale_Format::toFloat( 1234567.12345, $options                  ));
-        $this->assertEquals(    '1234567,12345-', Zend_Locale_Format::toFloat(-1234567.12345, $options                  ));
+        $this->assertEquals(  '1٬234٬567٫12345',  Zend_Locale_Format::toFloat( 1234567.12345, $options                  ));
+        $this->assertEquals(  '‏-1٬234٬567٫12345', Zend_Locale_Format::toFloat(-1234567.12345, $options                  ));
         $this->assertEquals(  '12,34,567.12345',  Zend_Locale_Format::toFloat( 1234567.12345, array('locale' => 'dz_BT')));
         $this->assertEquals(  '-1.234.567,12345', Zend_Locale_Format::toFloat(-1234567.12345, array('locale' => 'mk_MK')));
 
@@ -286,8 +286,8 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(          '0',  Zend_Locale_Format::toInteger(       0.1234567, $options));
         $this->assertEquals( '-1.234.567',  Zend_Locale_Format::toInteger(-1234567.12345,   $options));
         $this->assertEquals(  '1.234.567',  Zend_Locale_Format::toInteger( 1234567.12345,   $options));
-        $this->assertEquals(    '1234567',  Zend_Locale_Format::toInteger( 1234567.12345,   array('locale' => 'ar_QA')));
-        $this->assertEquals(    '1234567-', Zend_Locale_Format::toInteger(-1234567.12345,   array('locale' => 'ar_QA')));
+        $this->assertEquals(  '1٬234٬567',  Zend_Locale_Format::toInteger( 1234567.12345,   array('locale' => 'ar_QA')));
+        $this->assertEquals(  '‏-1٬234٬567', Zend_Locale_Format::toInteger(-1234567.12345,   array('locale' => 'ar_QA')));
         $this->assertEquals(  '12,34,567',  Zend_Locale_Format::toInteger( 1234567.12345,   array('locale' => 'dz_BT')));
         $this->assertEquals(  '-1.234.567', Zend_Locale_Format::toInteger(-1234567.12345,   array('locale' => 'mk_MK')));
 
@@ -372,7 +372,7 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
 
-        $value = Zend_Locale_Format::getDate('10 Nov 2006', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT'));
+        $value = Zend_Locale_Format::getDate('10 Nov. 2006', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT'));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
@@ -402,25 +402,25 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
             $this->assertRegexp('/unable.to.parse/i', $e->getMessage());
             // success
         }
-        $value = Zend_Locale_Format::getDate('Nov 10 2006', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT', 'fix_date' => true));
+        $value = Zend_Locale_Format::getDate('Nov. 10 2006', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT', 'fix_date' => true));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
 
 
         try {
-            $value = Zend_Locale_Format::getDate('2006 10 Nov', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT'));
+            $value = Zend_Locale_Format::getDate('2006 10 Nov.', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT'));
             $this->fail("exception expected");
         } catch (Zend_Locale_Exception $e) {
             $this->assertRegexp('/unable.to.parse/i', $e->getMessage());
             // success
         }
-        $value = Zend_Locale_Format::getDate('2006 10 Nov', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT', 'fix_date' => true));
+        $value = Zend_Locale_Format::getDate('2006 10 Nov.', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT', 'fix_date' => true));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
 
-        $value = Zend_Locale_Format::getDate('2006 Nov 10', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT', 'fix_date' => true));
+        $value = Zend_Locale_Format::getDate('2006 Nov. 10', array('date_format' => 'dd.MMM.yy', 'locale' => 'de_AT', 'fix_date' => true));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
@@ -474,12 +474,12 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(11, $value['month']);
         $this->assertEquals(2006,  $value['year'] );
 
-        $value = Zend_Locale_Format::getDate('10112006', array('locale' => 'de_AT'));
+        $value = Zend_Locale_Format::getDate('101106', array('locale' => 'de_AT'));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
 
-        $value = Zend_Locale_Format::getDate('10 Nov 2006', array('locale' => 'de_AT'));
+        $value = Zend_Locale_Format::getDate('10 Nov. 2006', array('locale' => 'de_AT'));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
@@ -520,7 +520,7 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
             $this->assertRegexp('/unable.to.parse/i', $e->getMessage());
             // success
         }
-        $value = Zend_Locale_Format::getDate('Nov 10 2006', array('locale' => 'de_AT', 'fix_date' => true));
+        $value = Zend_Locale_Format::getDate('Nov. 10 2006', array('locale' => 'de_AT', 'fix_date' => true));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
@@ -533,7 +533,7 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
             $this->assertRegexp('/unable.to.parse/i', $e->getMessage());
             // success
         }
-        $value = Zend_Locale_Format::getDate('2006 10 Nov', array('locale' => 'de_AT', 'fix_date' => true));
+        $value = Zend_Locale_Format::getDate('2006 10 Nov.', array('locale' => 'de_AT', 'fix_date' => true));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
@@ -569,7 +569,7 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(is_array(Zend_Locale_Format::getTime('13:14:55', array('date_format' => 'HH:mm:ss'))));
         Zend_Locale_Format::setOptions(array('format_type' => 'iso'));
 
-        $value = Zend_Locale_Format::getDate('2006 Nov 10', array('locale' => 'de_AT', 'fix_date' => true));
+        $value = Zend_Locale_Format::getDate('2006 Nov. 10', array('locale' => 'de_AT', 'fix_date' => true));
         $this->assertEquals(10,   $value['day']  );
         $this->assertEquals(11,   $value['month']);
         $this->assertEquals(2006, $value['year'] );
@@ -638,7 +638,7 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
      */
     public function testIsDate()
     {
-        $this->assertTrue( Zend_Locale_Format::checkDateFormat('13.Nov.2006', array('locale' => 'de_AT')));
+        $this->assertTrue( Zend_Locale_Format::checkDateFormat('13.11.2006', array('locale' => 'de_AT')));
         $this->assertFalse(Zend_Locale_Format::checkDateFormat('13.XXX.2006', array('locale' => 'ar_EG')));
         $this->assertFalse(Zend_Locale_Format::checkDateFormat('nodate'));
 
@@ -1053,7 +1053,7 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         $options = array('locale' => 'de_AT');
         $this->assertEquals('0,12345', Zend_Locale_Format::toFloat(.12345, $options));
         $options = array('locale' => 'ar_QA');
-        $this->assertEquals('0,12345',  Zend_Locale_Format::toFloat(.12345, $options));
+        $this->assertEquals('0٫12345',  Zend_Locale_Format::toFloat(.12345, $options));
 
         $this->assertTrue(Zend_Locale_Format::isFloat(',12345',  array('locale' => 'de_AT')));
 
@@ -1093,7 +1093,7 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('4,00', Zend_Locale_Format::toNumber(3.999, $options));
         $this->assertEquals('4,00', Zend_Locale_Format::toNumber(4, $options));
     }
-    
+
     /**
      * @group ZF-11837
      */
@@ -1102,7 +1102,7 @@ class Zend_Locale_FormatTest extends PHPUnit_Framework_TestCase
         try {
             setlocale(LC_ALL, 'en_US'); // test setup
             Zend_Locale_Format::setOptions(array('date_format' => 'yyyy-MM-dd'));
-            
+
             $this->assertTrue(Zend_Locale_Format::checkDateFormat('2011-10-21', array()));
         } catch ( PHPUnit_Framework_Error_Notice $ex ) {
             $this->fail('Zend_Locale_Format::checkDateFormat emitted unexpected E_NOTICE');
